@@ -3,9 +3,7 @@ from __future__ import annotations
 import logging
 import os
 import re
-from ast import literal_eval
 from collections import Counter
-from configparser import ConfigParser
 from copy import deepcopy
 from ctypes import c_size_t
 from io import BytesIO
@@ -18,6 +16,7 @@ from unicodedata import normalize
 import jsonpickle
 import magic
 import pdfplumber
+from dependency_injector.wiring import Provide, inject, as_
 from magic import MagicException
 from ocrmypdf import ocr
 from sortedcontainers import SortedSet
@@ -31,9 +30,12 @@ lock = Lock()
 
 
 class DocumentFileRepository:
-    def __init__(self, dir_path: Path, lang: str, recursive=False):
+    @inject
+    def __init__(self, dir_path: Path, recursive=False, lang: str = Provide['config.default.lang'],
+                 use_ocr: bool = Provide['config.default.ocr', as_(bool)]):
         self.lang = lang
         self.dir_path = dir_path
+        self._use_ocr = use_ocr
         self._recursive = recursive
         if not dir_path.is_dir():
             raise NotADirectoryError(f'The given path {dir_path} does not point to an existing directory!')
@@ -52,7 +54,7 @@ class DocumentFileRepository:
 
     def _read_file(self, file):
         if file.suffix == '.pdf':
-            reader = PdfReader(self.lang, file)
+            reader = PdfReader(file, self.lang, self._use_ocr)
             text = reader.extract_text()
             return models.Document(file.stem, str(file.resolve()), text)
         else:
@@ -98,28 +100,6 @@ class DocumentPairMatchesJsonRepository:
         return doc_pair_matches_list
 
 
-class ConfigFileRepository:
-    def __init__(self, config_path: Path):
-        if not config_path.is_file():
-            raise FileNotFoundError(f'The given path {config_path} does not point to an existing file!')
-        if not config_path.suffix == '.ini':
-            raise UnsupportedFileFormatError(f'The config file format must be INI.')
-        self.config_path = config_path
-        self._custom_config = {}
-
-    def get(self) -> dict:
-        parser = ConfigParser()
-        parser.read(self.config_path)
-        config = {}
-        for section in parser.sections():
-            typed_config = [(key, literal_eval(val)) for key, val in parser.items(section)]
-            config.update(dict(typed_config))
-        return {**config, **self._custom_config}
-
-    def update(self, config: dict):
-        self._custom_config = config
-
-
 class DocumentPickleRepository:
     def __init__(self, dir_path: Path, common_dir_path: Path = None):
         if not dir_path.is_dir():
@@ -143,15 +123,16 @@ class DocumentPickleRepository:
 
 
 class PdfReader:
-    ERROR_HEURISTIC = '¨[aou]|ﬀ|\(cid:\d+\)|\w{50}'
+    ERROR_HEURISTIC = '¨[aou]|ﬀ|\(cid:\d+\)|[a-zA-Z]{50}'
 
-    def __init__(self, lang, file):
-        self._lang = lang if lang == 'eng' else 'deu'
+    def __init__(self, file, lang, use_ocr):
         self._file = file
+        self._lang = lang if lang == 'eng' else 'deu'
+        self._use_ocr = use_ocr
 
     def extract_text(self):
         text = self._extract()
-        if self._poor_extraction(text):
+        if self._use_ocr and self._poor_extraction(text):
             log.warning(f"Poor text extraction in '{self._file.name}' detected! Using OCR...")
             with BytesIO() as ocr_file:
                 with lock:
